# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class CreatePKICertIssuer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allow_any_name': 'bool',
        'allow_subdomains': 'bool',
        'allowed_domains': 'str',
        'allowed_uri_sans': 'str',
        'client_flag': 'bool',
        'code_signing_flag': 'bool',
        'country': 'str',
        'delete_protection': 'str',
        'json': 'bool',
        'key_usage': 'str',
        'locality': 'str',
        'metadata': 'str',
        'name': 'str',
        'not_enforce_hostnames': 'bool',
        'not_require_cn': 'bool',
        'organizational_units': 'str',
        'organizations': 'str',
        'postal_code': 'str',
        'province': 'str',
        'server_flag': 'bool',
        'signer_key_name': 'str',
        'street_address': 'str',
        'tag': 'list[str]',
        'token': 'str',
        'ttl': 'int',
        'uid_token': 'str'
    }

    attribute_map = {
        'allow_any_name': 'allow-any-name',
        'allow_subdomains': 'allow-subdomains',
        'allowed_domains': 'allowed-domains',
        'allowed_uri_sans': 'allowed-uri-sans',
        'client_flag': 'client-flag',
        'code_signing_flag': 'code-signing-flag',
        'country': 'country',
        'delete_protection': 'delete_protection',
        'json': 'json',
        'key_usage': 'key-usage',
        'locality': 'locality',
        'metadata': 'metadata',
        'name': 'name',
        'not_enforce_hostnames': 'not-enforce-hostnames',
        'not_require_cn': 'not-require-cn',
        'organizational_units': 'organizational-units',
        'organizations': 'organizations',
        'postal_code': 'postal-code',
        'province': 'province',
        'server_flag': 'server-flag',
        'signer_key_name': 'signer-key-name',
        'street_address': 'street-address',
        'tag': 'tag',
        'token': 'token',
        'ttl': 'ttl',
        'uid_token': 'uid-token'
    }

    def __init__(self, allow_any_name=None, allow_subdomains=None, allowed_domains=None, allowed_uri_sans=None, client_flag=None, code_signing_flag=None, country=None, delete_protection=None, json=None, key_usage='DigitalSignature,KeyAgreement,KeyEncipherment', locality=None, metadata=None, name=None, not_enforce_hostnames=None, not_require_cn=None, organizational_units=None, organizations=None, postal_code=None, province=None, server_flag=None, signer_key_name=None, street_address=None, tag=None, token=None, ttl=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """CreatePKICertIssuer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allow_any_name = None
        self._allow_subdomains = None
        self._allowed_domains = None
        self._allowed_uri_sans = None
        self._client_flag = None
        self._code_signing_flag = None
        self._country = None
        self._delete_protection = None
        self._json = None
        self._key_usage = None
        self._locality = None
        self._metadata = None
        self._name = None
        self._not_enforce_hostnames = None
        self._not_require_cn = None
        self._organizational_units = None
        self._organizations = None
        self._postal_code = None
        self._province = None
        self._server_flag = None
        self._signer_key_name = None
        self._street_address = None
        self._tag = None
        self._token = None
        self._ttl = None
        self._uid_token = None
        self.discriminator = None

        if allow_any_name is not None:
            self.allow_any_name = allow_any_name
        if allow_subdomains is not None:
            self.allow_subdomains = allow_subdomains
        if allowed_domains is not None:
            self.allowed_domains = allowed_domains
        if allowed_uri_sans is not None:
            self.allowed_uri_sans = allowed_uri_sans
        if client_flag is not None:
            self.client_flag = client_flag
        if code_signing_flag is not None:
            self.code_signing_flag = code_signing_flag
        if country is not None:
            self.country = country
        if delete_protection is not None:
            self.delete_protection = delete_protection
        if json is not None:
            self.json = json
        if key_usage is not None:
            self.key_usage = key_usage
        if locality is not None:
            self.locality = locality
        if metadata is not None:
            self.metadata = metadata
        self.name = name
        if not_enforce_hostnames is not None:
            self.not_enforce_hostnames = not_enforce_hostnames
        if not_require_cn is not None:
            self.not_require_cn = not_require_cn
        if organizational_units is not None:
            self.organizational_units = organizational_units
        if organizations is not None:
            self.organizations = organizations
        if postal_code is not None:
            self.postal_code = postal_code
        if province is not None:
            self.province = province
        if server_flag is not None:
            self.server_flag = server_flag
        self.signer_key_name = signer_key_name
        if street_address is not None:
            self.street_address = street_address
        if tag is not None:
            self.tag = tag
        if token is not None:
            self.token = token
        self.ttl = ttl
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def allow_any_name(self):
        """Gets the allow_any_name of this CreatePKICertIssuer.  # noqa: E501

        If set, clients can request certificates for any CN  # noqa: E501

        :return: The allow_any_name of this CreatePKICertIssuer.  # noqa: E501
        :rtype: bool
        """
        return self._allow_any_name

    @allow_any_name.setter
    def allow_any_name(self, allow_any_name):
        """Sets the allow_any_name of this CreatePKICertIssuer.

        If set, clients can request certificates for any CN  # noqa: E501

        :param allow_any_name: The allow_any_name of this CreatePKICertIssuer.  # noqa: E501
        :type: bool
        """

        self._allow_any_name = allow_any_name

    @property
    def allow_subdomains(self):
        """Gets the allow_subdomains of this CreatePKICertIssuer.  # noqa: E501

        If set, clients can request certificates for subdomains and wildcard subdomains of the allowed domains  # noqa: E501

        :return: The allow_subdomains of this CreatePKICertIssuer.  # noqa: E501
        :rtype: bool
        """
        return self._allow_subdomains

    @allow_subdomains.setter
    def allow_subdomains(self, allow_subdomains):
        """Sets the allow_subdomains of this CreatePKICertIssuer.

        If set, clients can request certificates for subdomains and wildcard subdomains of the allowed domains  # noqa: E501

        :param allow_subdomains: The allow_subdomains of this CreatePKICertIssuer.  # noqa: E501
        :type: bool
        """

        self._allow_subdomains = allow_subdomains

    @property
    def allowed_domains(self):
        """Gets the allowed_domains of this CreatePKICertIssuer.  # noqa: E501

        A list of the allowed domains that clients can request to be included in the certificate (in a comma-delimited list)  # noqa: E501

        :return: The allowed_domains of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._allowed_domains

    @allowed_domains.setter
    def allowed_domains(self, allowed_domains):
        """Sets the allowed_domains of this CreatePKICertIssuer.

        A list of the allowed domains that clients can request to be included in the certificate (in a comma-delimited list)  # noqa: E501

        :param allowed_domains: The allowed_domains of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._allowed_domains = allowed_domains

    @property
    def allowed_uri_sans(self):
        """Gets the allowed_uri_sans of this CreatePKICertIssuer.  # noqa: E501

        A list of the allowed URIs that clients can request to be included in the certificate as part of the URI Subject Alternative Names (in a comma-delimited list)  # noqa: E501

        :return: The allowed_uri_sans of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._allowed_uri_sans

    @allowed_uri_sans.setter
    def allowed_uri_sans(self, allowed_uri_sans):
        """Sets the allowed_uri_sans of this CreatePKICertIssuer.

        A list of the allowed URIs that clients can request to be included in the certificate as part of the URI Subject Alternative Names (in a comma-delimited list)  # noqa: E501

        :param allowed_uri_sans: The allowed_uri_sans of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._allowed_uri_sans = allowed_uri_sans

    @property
    def client_flag(self):
        """Gets the client_flag of this CreatePKICertIssuer.  # noqa: E501

        If set, certificates will be flagged for client auth use  # noqa: E501

        :return: The client_flag of this CreatePKICertIssuer.  # noqa: E501
        :rtype: bool
        """
        return self._client_flag

    @client_flag.setter
    def client_flag(self, client_flag):
        """Sets the client_flag of this CreatePKICertIssuer.

        If set, certificates will be flagged for client auth use  # noqa: E501

        :param client_flag: The client_flag of this CreatePKICertIssuer.  # noqa: E501
        :type: bool
        """

        self._client_flag = client_flag

    @property
    def code_signing_flag(self):
        """Gets the code_signing_flag of this CreatePKICertIssuer.  # noqa: E501

        If set, certificates will be flagged for code signing use  # noqa: E501

        :return: The code_signing_flag of this CreatePKICertIssuer.  # noqa: E501
        :rtype: bool
        """
        return self._code_signing_flag

    @code_signing_flag.setter
    def code_signing_flag(self, code_signing_flag):
        """Sets the code_signing_flag of this CreatePKICertIssuer.

        If set, certificates will be flagged for code signing use  # noqa: E501

        :param code_signing_flag: The code_signing_flag of this CreatePKICertIssuer.  # noqa: E501
        :type: bool
        """

        self._code_signing_flag = code_signing_flag

    @property
    def country(self):
        """Gets the country of this CreatePKICertIssuer.  # noqa: E501

        A comma-separated list of countries that will be set in the issued certificate  # noqa: E501

        :return: The country of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this CreatePKICertIssuer.

        A comma-separated list of countries that will be set in the issued certificate  # noqa: E501

        :param country: The country of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def delete_protection(self):
        """Gets the delete_protection of this CreatePKICertIssuer.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this CreatePKICertIssuer.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def json(self):
        """Gets the json of this CreatePKICertIssuer.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this CreatePKICertIssuer.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this CreatePKICertIssuer.

        Set output format to JSON  # noqa: E501

        :param json: The json of this CreatePKICertIssuer.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def key_usage(self):
        """Gets the key_usage of this CreatePKICertIssuer.  # noqa: E501

        key-usage  # noqa: E501

        :return: The key_usage of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._key_usage

    @key_usage.setter
    def key_usage(self, key_usage):
        """Sets the key_usage of this CreatePKICertIssuer.

        key-usage  # noqa: E501

        :param key_usage: The key_usage of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._key_usage = key_usage

    @property
    def locality(self):
        """Gets the locality of this CreatePKICertIssuer.  # noqa: E501

        A comma-separated list of localities that will be set in the issued certificate  # noqa: E501

        :return: The locality of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """Sets the locality of this CreatePKICertIssuer.

        A comma-separated list of localities that will be set in the issued certificate  # noqa: E501

        :param locality: The locality of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._locality = locality

    @property
    def metadata(self):
        """Gets the metadata of this CreatePKICertIssuer.  # noqa: E501

        A metadata about the issuer  # noqa: E501

        :return: The metadata of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this CreatePKICertIssuer.

        A metadata about the issuer  # noqa: E501

        :param metadata: The metadata of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._metadata = metadata

    @property
    def name(self):
        """Gets the name of this CreatePKICertIssuer.  # noqa: E501

        PKI certificate issuer name  # noqa: E501

        :return: The name of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreatePKICertIssuer.

        PKI certificate issuer name  # noqa: E501

        :param name: The name of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def not_enforce_hostnames(self):
        """Gets the not_enforce_hostnames of this CreatePKICertIssuer.  # noqa: E501

        If set, any names are allowed for CN and SANs in the certificate and not only a valid host name  # noqa: E501

        :return: The not_enforce_hostnames of this CreatePKICertIssuer.  # noqa: E501
        :rtype: bool
        """
        return self._not_enforce_hostnames

    @not_enforce_hostnames.setter
    def not_enforce_hostnames(self, not_enforce_hostnames):
        """Sets the not_enforce_hostnames of this CreatePKICertIssuer.

        If set, any names are allowed for CN and SANs in the certificate and not only a valid host name  # noqa: E501

        :param not_enforce_hostnames: The not_enforce_hostnames of this CreatePKICertIssuer.  # noqa: E501
        :type: bool
        """

        self._not_enforce_hostnames = not_enforce_hostnames

    @property
    def not_require_cn(self):
        """Gets the not_require_cn of this CreatePKICertIssuer.  # noqa: E501

        If set, clients can request certificates without a CN  # noqa: E501

        :return: The not_require_cn of this CreatePKICertIssuer.  # noqa: E501
        :rtype: bool
        """
        return self._not_require_cn

    @not_require_cn.setter
    def not_require_cn(self, not_require_cn):
        """Sets the not_require_cn of this CreatePKICertIssuer.

        If set, clients can request certificates without a CN  # noqa: E501

        :param not_require_cn: The not_require_cn of this CreatePKICertIssuer.  # noqa: E501
        :type: bool
        """

        self._not_require_cn = not_require_cn

    @property
    def organizational_units(self):
        """Gets the organizational_units of this CreatePKICertIssuer.  # noqa: E501

        A comma-separated list of organizational units (OU) that will be set in the issued certificate  # noqa: E501

        :return: The organizational_units of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._organizational_units

    @organizational_units.setter
    def organizational_units(self, organizational_units):
        """Sets the organizational_units of this CreatePKICertIssuer.

        A comma-separated list of organizational units (OU) that will be set in the issued certificate  # noqa: E501

        :param organizational_units: The organizational_units of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._organizational_units = organizational_units

    @property
    def organizations(self):
        """Gets the organizations of this CreatePKICertIssuer.  # noqa: E501

        A comma-separated list of organizations (O) that will be set in the issued certificate  # noqa: E501

        :return: The organizations of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._organizations

    @organizations.setter
    def organizations(self, organizations):
        """Sets the organizations of this CreatePKICertIssuer.

        A comma-separated list of organizations (O) that will be set in the issued certificate  # noqa: E501

        :param organizations: The organizations of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._organizations = organizations

    @property
    def postal_code(self):
        """Gets the postal_code of this CreatePKICertIssuer.  # noqa: E501

        A comma-separated list of postal codes that will be set in the issued certificate  # noqa: E501

        :return: The postal_code of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this CreatePKICertIssuer.

        A comma-separated list of postal codes that will be set in the issued certificate  # noqa: E501

        :param postal_code: The postal_code of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    @property
    def province(self):
        """Gets the province of this CreatePKICertIssuer.  # noqa: E501

        A comma-separated list of provinces that will be set in the issued certificate  # noqa: E501

        :return: The province of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._province

    @province.setter
    def province(self, province):
        """Sets the province of this CreatePKICertIssuer.

        A comma-separated list of provinces that will be set in the issued certificate  # noqa: E501

        :param province: The province of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._province = province

    @property
    def server_flag(self):
        """Gets the server_flag of this CreatePKICertIssuer.  # noqa: E501

        If set, certificates will be flagged for server auth use  # noqa: E501

        :return: The server_flag of this CreatePKICertIssuer.  # noqa: E501
        :rtype: bool
        """
        return self._server_flag

    @server_flag.setter
    def server_flag(self, server_flag):
        """Sets the server_flag of this CreatePKICertIssuer.

        If set, certificates will be flagged for server auth use  # noqa: E501

        :param server_flag: The server_flag of this CreatePKICertIssuer.  # noqa: E501
        :type: bool
        """

        self._server_flag = server_flag

    @property
    def signer_key_name(self):
        """Gets the signer_key_name of this CreatePKICertIssuer.  # noqa: E501

        A key to sign the certificate with  # noqa: E501

        :return: The signer_key_name of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._signer_key_name

    @signer_key_name.setter
    def signer_key_name(self, signer_key_name):
        """Sets the signer_key_name of this CreatePKICertIssuer.

        A key to sign the certificate with  # noqa: E501

        :param signer_key_name: The signer_key_name of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and signer_key_name is None:  # noqa: E501
            raise ValueError("Invalid value for `signer_key_name`, must not be `None`")  # noqa: E501

        self._signer_key_name = signer_key_name

    @property
    def street_address(self):
        """Gets the street_address of this CreatePKICertIssuer.  # noqa: E501

        A comma-separated list of street addresses that will be set in the issued certificate  # noqa: E501

        :return: The street_address of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._street_address

    @street_address.setter
    def street_address(self, street_address):
        """Sets the street_address of this CreatePKICertIssuer.

        A comma-separated list of street addresses that will be set in the issued certificate  # noqa: E501

        :param street_address: The street_address of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._street_address = street_address

    @property
    def tag(self):
        """Gets the tag of this CreatePKICertIssuer.  # noqa: E501

        List of the tags attached to this key  # noqa: E501

        :return: The tag of this CreatePKICertIssuer.  # noqa: E501
        :rtype: list[str]
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this CreatePKICertIssuer.

        List of the tags attached to this key  # noqa: E501

        :param tag: The tag of this CreatePKICertIssuer.  # noqa: E501
        :type: list[str]
        """

        self._tag = tag

    @property
    def token(self):
        """Gets the token of this CreatePKICertIssuer.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this CreatePKICertIssuer.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def ttl(self):
        """Gets the ttl of this CreatePKICertIssuer.  # noqa: E501

        he requested Time To Live for the certificate, in seconds  # noqa: E501

        :return: The ttl of this CreatePKICertIssuer.  # noqa: E501
        :rtype: int
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """Sets the ttl of this CreatePKICertIssuer.

        he requested Time To Live for the certificate, in seconds  # noqa: E501

        :param ttl: The ttl of this CreatePKICertIssuer.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and ttl is None:  # noqa: E501
            raise ValueError("Invalid value for `ttl`, must not be `None`")  # noqa: E501

        self._ttl = ttl

    @property
    def uid_token(self):
        """Gets the uid_token of this CreatePKICertIssuer.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this CreatePKICertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this CreatePKICertIssuer.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this CreatePKICertIssuer.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreatePKICertIssuer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreatePKICertIssuer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class Auth(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_id': 'str',
        'access_key': 'str',
        'access_type': 'str',
        'admin_email': 'str',
        'admin_password': 'str',
        'cert_data': 'str',
        'cloud_id': 'str',
        'debug': 'bool',
        'gateway_url': 'str',
        'gcp_audience': 'str',
        'json': 'bool',
        'jwt': 'str',
        'k8s_auth_config_name': 'str',
        'k8s_service_account_token': 'str',
        'key_data': 'str',
        'ldap_password': 'str',
        'ldap_username': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'access_id': 'access-id',
        'access_key': 'access-key',
        'access_type': 'access-type',
        'admin_email': 'admin-email',
        'admin_password': 'admin-password',
        'cert_data': 'cert-data',
        'cloud_id': 'cloud-id',
        'debug': 'debug',
        'gateway_url': 'gateway-url',
        'gcp_audience': 'gcp-audience',
        'json': 'json',
        'jwt': 'jwt',
        'k8s_auth_config_name': 'k8s-auth-config-name',
        'k8s_service_account_token': 'k8s-service-account-token',
        'key_data': 'key-data',
        'ldap_password': 'ldap_password',
        'ldap_username': 'ldap_username',
        'uid_token': 'uid_token'
    }

    def __init__(self, access_id=None, access_key=None, access_type='access_key', admin_email=None, admin_password=None, cert_data=None, cloud_id=None, debug=None, gateway_url=None, gcp_audience=None, json=None, jwt=None, k8s_auth_config_name=None, k8s_service_account_token=None, key_data=None, ldap_password=None, ldap_username=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """Auth - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_id = None
        self._access_key = None
        self._access_type = None
        self._admin_email = None
        self._admin_password = None
        self._cert_data = None
        self._cloud_id = None
        self._debug = None
        self._gateway_url = None
        self._gcp_audience = None
        self._json = None
        self._jwt = None
        self._k8s_auth_config_name = None
        self._k8s_service_account_token = None
        self._key_data = None
        self._ldap_password = None
        self._ldap_username = None
        self._uid_token = None
        self.discriminator = None

        if access_id is not None:
            self.access_id = access_id
        if access_key is not None:
            self.access_key = access_key
        if access_type is not None:
            self.access_type = access_type
        if admin_email is not None:
            self.admin_email = admin_email
        if admin_password is not None:
            self.admin_password = admin_password
        if cert_data is not None:
            self.cert_data = cert_data
        if cloud_id is not None:
            self.cloud_id = cloud_id
        if debug is not None:
            self.debug = debug
        if gateway_url is not None:
            self.gateway_url = gateway_url
        if gcp_audience is not None:
            self.gcp_audience = gcp_audience
        if json is not None:
            self.json = json
        if jwt is not None:
            self.jwt = jwt
        if k8s_auth_config_name is not None:
            self.k8s_auth_config_name = k8s_auth_config_name
        if k8s_service_account_token is not None:
            self.k8s_service_account_token = k8s_service_account_token
        if key_data is not None:
            self.key_data = key_data
        if ldap_password is not None:
            self.ldap_password = ldap_password
        if ldap_username is not None:
            self.ldap_username = ldap_username
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def access_id(self):
        """Gets the access_id of this Auth.  # noqa: E501

        Access ID  # noqa: E501

        :return: The access_id of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._access_id

    @access_id.setter
    def access_id(self, access_id):
        """Sets the access_id of this Auth.

        Access ID  # noqa: E501

        :param access_id: The access_id of this Auth.  # noqa: E501
        :type: str
        """

        self._access_id = access_id

    @property
    def access_key(self):
        """Gets the access_key of this Auth.  # noqa: E501

        Access key (relevant only for access-type=access_key)  # noqa: E501

        :return: The access_key of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._access_key

    @access_key.setter
    def access_key(self, access_key):
        """Sets the access_key of this Auth.

        Access key (relevant only for access-type=access_key)  # noqa: E501

        :param access_key: The access_key of this Auth.  # noqa: E501
        :type: str
        """

        self._access_key = access_key

    @property
    def access_type(self):
        """Gets the access_type of this Auth.  # noqa: E501

        Access Type (access_key/password/saml/ldap/k8s/azure_ad/oidc/aws_iam/universal_identity/jwt/gcp/cert)  # noqa: E501

        :return: The access_type of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._access_type

    @access_type.setter
    def access_type(self, access_type):
        """Sets the access_type of this Auth.

        Access Type (access_key/password/saml/ldap/k8s/azure_ad/oidc/aws_iam/universal_identity/jwt/gcp/cert)  # noqa: E501

        :param access_type: The access_type of this Auth.  # noqa: E501
        :type: str
        """

        self._access_type = access_type

    @property
    def admin_email(self):
        """Gets the admin_email of this Auth.  # noqa: E501

        Email (relevant only for access-type=password)  # noqa: E501

        :return: The admin_email of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._admin_email

    @admin_email.setter
    def admin_email(self, admin_email):
        """Sets the admin_email of this Auth.

        Email (relevant only for access-type=password)  # noqa: E501

        :param admin_email: The admin_email of this Auth.  # noqa: E501
        :type: str
        """

        self._admin_email = admin_email

    @property
    def admin_password(self):
        """Gets the admin_password of this Auth.  # noqa: E501

        Password (relevant only for access-type=password)  # noqa: E501

        :return: The admin_password of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._admin_password

    @admin_password.setter
    def admin_password(self, admin_password):
        """Sets the admin_password of this Auth.

        Password (relevant only for access-type=password)  # noqa: E501

        :param admin_password: The admin_password of this Auth.  # noqa: E501
        :type: str
        """

        self._admin_password = admin_password

    @property
    def cert_data(self):
        """Gets the cert_data of this Auth.  # noqa: E501

        Certificate data encoded in base64. Used if file was not provided. (relevant only for access-type=cert)  # noqa: E501

        :return: The cert_data of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._cert_data

    @cert_data.setter
    def cert_data(self, cert_data):
        """Sets the cert_data of this Auth.

        Certificate data encoded in base64. Used if file was not provided. (relevant only for access-type=cert)  # noqa: E501

        :param cert_data: The cert_data of this Auth.  # noqa: E501
        :type: str
        """

        self._cert_data = cert_data

    @property
    def cloud_id(self):
        """Gets the cloud_id of this Auth.  # noqa: E501

        The cloud identity (relevant only for access-type=azure_ad,aws_iam,gcp)  # noqa: E501

        :return: The cloud_id of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._cloud_id

    @cloud_id.setter
    def cloud_id(self, cloud_id):
        """Sets the cloud_id of this Auth.

        The cloud identity (relevant only for access-type=azure_ad,aws_iam,gcp)  # noqa: E501

        :param cloud_id: The cloud_id of this Auth.  # noqa: E501
        :type: str
        """

        self._cloud_id = cloud_id

    @property
    def debug(self):
        """Gets the debug of this Auth.  # noqa: E501


        :return: The debug of this Auth.  # noqa: E501
        :rtype: bool
        """
        return self._debug

    @debug.setter
    def debug(self, debug):
        """Sets the debug of this Auth.


        :param debug: The debug of this Auth.  # noqa: E501
        :type: bool
        """

        self._debug = debug

    @property
    def gateway_url(self):
        """Gets the gateway_url of this Auth.  # noqa: E501

        Gateway URL for the K8S authenticated (relevant only for access-type=k8s)  # noqa: E501

        :return: The gateway_url of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._gateway_url

    @gateway_url.setter
    def gateway_url(self, gateway_url):
        """Sets the gateway_url of this Auth.

        Gateway URL for the K8S authenticated (relevant only for access-type=k8s)  # noqa: E501

        :param gateway_url: The gateway_url of this Auth.  # noqa: E501
        :type: str
        """

        self._gateway_url = gateway_url

    @property
    def gcp_audience(self):
        """Gets the gcp_audience of this Auth.  # noqa: E501

        GCP JWT audience  # noqa: E501

        :return: The gcp_audience of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._gcp_audience

    @gcp_audience.setter
    def gcp_audience(self, gcp_audience):
        """Sets the gcp_audience of this Auth.

        GCP JWT audience  # noqa: E501

        :param gcp_audience: The gcp_audience of this Auth.  # noqa: E501
        :type: str
        """

        self._gcp_audience = gcp_audience

    @property
    def json(self):
        """Gets the json of this Auth.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this Auth.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this Auth.

        Set output format to JSON  # noqa: E501

        :param json: The json of this Auth.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def jwt(self):
        """Gets the jwt of this Auth.  # noqa: E501

        The Json Web Token (relevant only for access-type=jwt/oidc)  # noqa: E501

        :return: The jwt of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._jwt

    @jwt.setter
    def jwt(self, jwt):
        """Sets the jwt of this Auth.

        The Json Web Token (relevant only for access-type=jwt/oidc)  # noqa: E501

        :param jwt: The jwt of this Auth.  # noqa: E501
        :type: str
        """

        self._jwt = jwt

    @property
    def k8s_auth_config_name(self):
        """Gets the k8s_auth_config_name of this Auth.  # noqa: E501

        The K8S Auth config name (relevant only for access-type=k8s)  # noqa: E501

        :return: The k8s_auth_config_name of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._k8s_auth_config_name

    @k8s_auth_config_name.setter
    def k8s_auth_config_name(self, k8s_auth_config_name):
        """Sets the k8s_auth_config_name of this Auth.

        The K8S Auth config name (relevant only for access-type=k8s)  # noqa: E501

        :param k8s_auth_config_name: The k8s_auth_config_name of this Auth.  # noqa: E501
        :type: str
        """

        self._k8s_auth_config_name = k8s_auth_config_name

    @property
    def k8s_service_account_token(self):
        """Gets the k8s_service_account_token of this Auth.  # noqa: E501

        The K8S service account token. (relevant only for access-type=k8s)  # noqa: E501

        :return: The k8s_service_account_token of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._k8s_service_account_token

    @k8s_service_account_token.setter
    def k8s_service_account_token(self, k8s_service_account_token):
        """Sets the k8s_service_account_token of this Auth.

        The K8S service account token. (relevant only for access-type=k8s)  # noqa: E501

        :param k8s_service_account_token: The k8s_service_account_token of this Auth.  # noqa: E501
        :type: str
        """

        self._k8s_service_account_token = k8s_service_account_token

    @property
    def key_data(self):
        """Gets the key_data of this Auth.  # noqa: E501

        Private key data encoded in base64. Used if file was not provided.(relevant only for access-type=cert)  # noqa: E501

        :return: The key_data of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._key_data

    @key_data.setter
    def key_data(self, key_data):
        """Sets the key_data of this Auth.

        Private key data encoded in base64. Used if file was not provided.(relevant only for access-type=cert)  # noqa: E501

        :param key_data: The key_data of this Auth.  # noqa: E501
        :type: str
        """

        self._key_data = key_data

    @property
    def ldap_password(self):
        """Gets the ldap_password of this Auth.  # noqa: E501

        LDAP password (relevant only for access-type=ldap)  # noqa: E501

        :return: The ldap_password of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._ldap_password

    @ldap_password.setter
    def ldap_password(self, ldap_password):
        """Sets the ldap_password of this Auth.

        LDAP password (relevant only for access-type=ldap)  # noqa: E501

        :param ldap_password: The ldap_password of this Auth.  # noqa: E501
        :type: str
        """

        self._ldap_password = ldap_password

    @property
    def ldap_username(self):
        """Gets the ldap_username of this Auth.  # noqa: E501

        LDAP username (relevant only for access-type=ldap)  # noqa: E501

        :return: The ldap_username of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._ldap_username

    @ldap_username.setter
    def ldap_username(self, ldap_username):
        """Sets the ldap_username of this Auth.

        LDAP username (relevant only for access-type=ldap)  # noqa: E501

        :param ldap_username: The ldap_username of this Auth.  # noqa: E501
        :type: str
        """

        self._ldap_username = ldap_username

    @property
    def uid_token(self):
        """Gets the uid_token of this Auth.  # noqa: E501

        The universal_identity token (relevant only for access-type=universal_identity)  # noqa: E501

        :return: The uid_token of this Auth.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this Auth.

        The universal_identity token (relevant only for access-type=universal_identity)  # noqa: E501

        :param uid_token: The uid_token of this Auth.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Auth):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Auth):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayCreateProducerHanaDb(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'delete_protection': 'str',
        'hana_dbname': 'str',
        'hanadb_create_statements': 'str',
        'hanadb_host': 'str',
        'hanadb_password': 'str',
        'hanadb_port': 'str',
        'hanadb_revocation_statements': 'str',
        'hanadb_username': 'str',
        'json': 'bool',
        'name': 'str',
        'producer_encryption_key_name': 'str',
        'secure_access_bastion_issuer': 'str',
        'secure_access_db_schema': 'str',
        'secure_access_enable': 'str',
        'secure_access_host': 'list[str]',
        'secure_access_web': 'bool',
        'tags': 'list[str]',
        'target_name': 'str',
        'token': 'str',
        'uid_token': 'str',
        'user_ttl': 'str'
    }

    attribute_map = {
        'delete_protection': 'delete_protection',
        'hana_dbname': 'hana-dbname',
        'hanadb_create_statements': 'hanadb-create-statements',
        'hanadb_host': 'hanadb-host',
        'hanadb_password': 'hanadb-password',
        'hanadb_port': 'hanadb-port',
        'hanadb_revocation_statements': 'hanadb-revocation-statements',
        'hanadb_username': 'hanadb-username',
        'json': 'json',
        'name': 'name',
        'producer_encryption_key_name': 'producer-encryption-key-name',
        'secure_access_bastion_issuer': 'secure-access-bastion-issuer',
        'secure_access_db_schema': 'secure-access-db-schema',
        'secure_access_enable': 'secure-access-enable',
        'secure_access_host': 'secure-access-host',
        'secure_access_web': 'secure-access-web',
        'tags': 'tags',
        'target_name': 'target-name',
        'token': 'token',
        'uid_token': 'uid-token',
        'user_ttl': 'user-ttl'
    }

    def __init__(self, delete_protection=None, hana_dbname=None, hanadb_create_statements=None, hanadb_host='127.0.0.1', hanadb_password=None, hanadb_port='443', hanadb_revocation_statements=None, hanadb_username=None, json=None, name=None, producer_encryption_key_name=None, secure_access_bastion_issuer=None, secure_access_db_schema=None, secure_access_enable=None, secure_access_host=None, secure_access_web=None, tags=None, target_name=None, token=None, uid_token=None, user_ttl='60m', local_vars_configuration=None):  # noqa: E501
        """GatewayCreateProducerHanaDb - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._delete_protection = None
        self._hana_dbname = None
        self._hanadb_create_statements = None
        self._hanadb_host = None
        self._hanadb_password = None
        self._hanadb_port = None
        self._hanadb_revocation_statements = None
        self._hanadb_username = None
        self._json = None
        self._name = None
        self._producer_encryption_key_name = None
        self._secure_access_bastion_issuer = None
        self._secure_access_db_schema = None
        self._secure_access_enable = None
        self._secure_access_host = None
        self._secure_access_web = None
        self._tags = None
        self._target_name = None
        self._token = None
        self._uid_token = None
        self._user_ttl = None
        self.discriminator = None

        if delete_protection is not None:
            self.delete_protection = delete_protection
        if hana_dbname is not None:
            self.hana_dbname = hana_dbname
        if hanadb_create_statements is not None:
            self.hanadb_create_statements = hanadb_create_statements
        if hanadb_host is not None:
            self.hanadb_host = hanadb_host
        if hanadb_password is not None:
            self.hanadb_password = hanadb_password
        if hanadb_port is not None:
            self.hanadb_port = hanadb_port
        if hanadb_revocation_statements is not None:
            self.hanadb_revocation_statements = hanadb_revocation_statements
        if hanadb_username is not None:
            self.hanadb_username = hanadb_username
        if json is not None:
            self.json = json
        self.name = name
        if producer_encryption_key_name is not None:
            self.producer_encryption_key_name = producer_encryption_key_name
        if secure_access_bastion_issuer is not None:
            self.secure_access_bastion_issuer = secure_access_bastion_issuer
        if secure_access_db_schema is not None:
            self.secure_access_db_schema = secure_access_db_schema
        if secure_access_enable is not None:
            self.secure_access_enable = secure_access_enable
        if secure_access_host is not None:
            self.secure_access_host = secure_access_host
        if secure_access_web is not None:
            self.secure_access_web = secure_access_web
        if tags is not None:
            self.tags = tags
        if target_name is not None:
            self.target_name = target_name
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if user_ttl is not None:
            self.user_ttl = user_ttl

    @property
    def delete_protection(self):
        """Gets the delete_protection of this GatewayCreateProducerHanaDb.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this GatewayCreateProducerHanaDb.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def hana_dbname(self):
        """Gets the hana_dbname of this GatewayCreateProducerHanaDb.  # noqa: E501

        HanaDb Name  # noqa: E501

        :return: The hana_dbname of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._hana_dbname

    @hana_dbname.setter
    def hana_dbname(self, hana_dbname):
        """Sets the hana_dbname of this GatewayCreateProducerHanaDb.

        HanaDb Name  # noqa: E501

        :param hana_dbname: The hana_dbname of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._hana_dbname = hana_dbname

    @property
    def hanadb_create_statements(self):
        """Gets the hanadb_create_statements of this GatewayCreateProducerHanaDb.  # noqa: E501

        HanaDb Creation statements  # noqa: E501

        :return: The hanadb_create_statements of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._hanadb_create_statements

    @hanadb_create_statements.setter
    def hanadb_create_statements(self, hanadb_create_statements):
        """Sets the hanadb_create_statements of this GatewayCreateProducerHanaDb.

        HanaDb Creation statements  # noqa: E501

        :param hanadb_create_statements: The hanadb_create_statements of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._hanadb_create_statements = hanadb_create_statements

    @property
    def hanadb_host(self):
        """Gets the hanadb_host of this GatewayCreateProducerHanaDb.  # noqa: E501

        HanaDb Host  # noqa: E501

        :return: The hanadb_host of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._hanadb_host

    @hanadb_host.setter
    def hanadb_host(self, hanadb_host):
        """Sets the hanadb_host of this GatewayCreateProducerHanaDb.

        HanaDb Host  # noqa: E501

        :param hanadb_host: The hanadb_host of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._hanadb_host = hanadb_host

    @property
    def hanadb_password(self):
        """Gets the hanadb_password of this GatewayCreateProducerHanaDb.  # noqa: E501

        HanaDb Password  # noqa: E501

        :return: The hanadb_password of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._hanadb_password

    @hanadb_password.setter
    def hanadb_password(self, hanadb_password):
        """Sets the hanadb_password of this GatewayCreateProducerHanaDb.

        HanaDb Password  # noqa: E501

        :param hanadb_password: The hanadb_password of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._hanadb_password = hanadb_password

    @property
    def hanadb_port(self):
        """Gets the hanadb_port of this GatewayCreateProducerHanaDb.  # noqa: E501

        HanaDb Port  # noqa: E501

        :return: The hanadb_port of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._hanadb_port

    @hanadb_port.setter
    def hanadb_port(self, hanadb_port):
        """Sets the hanadb_port of this GatewayCreateProducerHanaDb.

        HanaDb Port  # noqa: E501

        :param hanadb_port: The hanadb_port of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._hanadb_port = hanadb_port

    @property
    def hanadb_revocation_statements(self):
        """Gets the hanadb_revocation_statements of this GatewayCreateProducerHanaDb.  # noqa: E501

        HanaDb Revocation statements  # noqa: E501

        :return: The hanadb_revocation_statements of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._hanadb_revocation_statements

    @hanadb_revocation_statements.setter
    def hanadb_revocation_statements(self, hanadb_revocation_statements):
        """Sets the hanadb_revocation_statements of this GatewayCreateProducerHanaDb.

        HanaDb Revocation statements  # noqa: E501

        :param hanadb_revocation_statements: The hanadb_revocation_statements of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._hanadb_revocation_statements = hanadb_revocation_statements

    @property
    def hanadb_username(self):
        """Gets the hanadb_username of this GatewayCreateProducerHanaDb.  # noqa: E501

        HanaDb Username  # noqa: E501

        :return: The hanadb_username of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._hanadb_username

    @hanadb_username.setter
    def hanadb_username(self, hanadb_username):
        """Sets the hanadb_username of this GatewayCreateProducerHanaDb.

        HanaDb Username  # noqa: E501

        :param hanadb_username: The hanadb_username of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._hanadb_username = hanadb_username

    @property
    def json(self):
        """Gets the json of this GatewayCreateProducerHanaDb.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayCreateProducerHanaDb.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this GatewayCreateProducerHanaDb.  # noqa: E501

        Producer name  # noqa: E501

        :return: The name of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayCreateProducerHanaDb.

        Producer name  # noqa: E501

        :param name: The name of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def producer_encryption_key_name(self):
        """Gets the producer_encryption_key_name of this GatewayCreateProducerHanaDb.  # noqa: E501

        Dynamic producer encryption key  # noqa: E501

        :return: The producer_encryption_key_name of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._producer_encryption_key_name

    @producer_encryption_key_name.setter
    def producer_encryption_key_name(self, producer_encryption_key_name):
        """Sets the producer_encryption_key_name of this GatewayCreateProducerHanaDb.

        Dynamic producer encryption key  # noqa: E501

        :param producer_encryption_key_name: The producer_encryption_key_name of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._producer_encryption_key_name = producer_encryption_key_name

    @property
    def secure_access_bastion_issuer(self):
        """Gets the secure_access_bastion_issuer of this GatewayCreateProducerHanaDb.  # noqa: E501


        :return: The secure_access_bastion_issuer of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_bastion_issuer

    @secure_access_bastion_issuer.setter
    def secure_access_bastion_issuer(self, secure_access_bastion_issuer):
        """Sets the secure_access_bastion_issuer of this GatewayCreateProducerHanaDb.


        :param secure_access_bastion_issuer: The secure_access_bastion_issuer of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._secure_access_bastion_issuer = secure_access_bastion_issuer

    @property
    def secure_access_db_schema(self):
        """Gets the secure_access_db_schema of this GatewayCreateProducerHanaDb.  # noqa: E501


        :return: The secure_access_db_schema of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_db_schema

    @secure_access_db_schema.setter
    def secure_access_db_schema(self, secure_access_db_schema):
        """Sets the secure_access_db_schema of this GatewayCreateProducerHanaDb.


        :param secure_access_db_schema: The secure_access_db_schema of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._secure_access_db_schema = secure_access_db_schema

    @property
    def secure_access_enable(self):
        """Gets the secure_access_enable of this GatewayCreateProducerHanaDb.  # noqa: E501


        :return: The secure_access_enable of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_enable

    @secure_access_enable.setter
    def secure_access_enable(self, secure_access_enable):
        """Sets the secure_access_enable of this GatewayCreateProducerHanaDb.


        :param secure_access_enable: The secure_access_enable of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._secure_access_enable = secure_access_enable

    @property
    def secure_access_host(self):
        """Gets the secure_access_host of this GatewayCreateProducerHanaDb.  # noqa: E501


        :return: The secure_access_host of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: list[str]
        """
        return self._secure_access_host

    @secure_access_host.setter
    def secure_access_host(self, secure_access_host):
        """Sets the secure_access_host of this GatewayCreateProducerHanaDb.


        :param secure_access_host: The secure_access_host of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: list[str]
        """

        self._secure_access_host = secure_access_host

    @property
    def secure_access_web(self):
        """Gets the secure_access_web of this GatewayCreateProducerHanaDb.  # noqa: E501


        :return: The secure_access_web of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_web

    @secure_access_web.setter
    def secure_access_web(self, secure_access_web):
        """Sets the secure_access_web of this GatewayCreateProducerHanaDb.


        :param secure_access_web: The secure_access_web of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: bool
        """

        self._secure_access_web = secure_access_web

    @property
    def tags(self):
        """Gets the tags of this GatewayCreateProducerHanaDb.  # noqa: E501

        List of the tags attached to this secret  # noqa: E501

        :return: The tags of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this GatewayCreateProducerHanaDb.

        List of the tags attached to this secret  # noqa: E501

        :param tags: The tags of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def target_name(self):
        """Gets the target_name of this GatewayCreateProducerHanaDb.  # noqa: E501

        Target name  # noqa: E501

        :return: The target_name of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this GatewayCreateProducerHanaDb.

        Target name  # noqa: E501

        :param target_name: The target_name of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._target_name = target_name

    @property
    def token(self):
        """Gets the token of this GatewayCreateProducerHanaDb.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayCreateProducerHanaDb.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayCreateProducerHanaDb.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayCreateProducerHanaDb.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def user_ttl(self):
        """Gets the user_ttl of this GatewayCreateProducerHanaDb.  # noqa: E501

        User TTL  # noqa: E501

        :return: The user_ttl of this GatewayCreateProducerHanaDb.  # noqa: E501
        :rtype: str
        """
        return self._user_ttl

    @user_ttl.setter
    def user_ttl(self, user_ttl):
        """Sets the user_ttl of this GatewayCreateProducerHanaDb.

        User TTL  # noqa: E501

        :param user_ttl: The user_ttl of this GatewayCreateProducerHanaDb.  # noqa: E501
        :type: str
        """

        self._user_ttl = user_ttl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayCreateProducerHanaDb):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayCreateProducerHanaDb):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class CertificateIssueInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cert_issuer_type': 'str',
        'max_ttl': 'int',
        'pki_cert_issuer_details': 'PKICertificateIssueDetails',
        'ssh_cert_issuer_details': 'SSHCertificateIssueDetails'
    }

    attribute_map = {
        'cert_issuer_type': 'cert_issuer_type',
        'max_ttl': 'max_ttl',
        'pki_cert_issuer_details': 'pki_cert_issuer_details',
        'ssh_cert_issuer_details': 'ssh_cert_issuer_details'
    }

    def __init__(self, cert_issuer_type=None, max_ttl=None, pki_cert_issuer_details=None, ssh_cert_issuer_details=None, local_vars_configuration=None):  # noqa: E501
        """CertificateIssueInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cert_issuer_type = None
        self._max_ttl = None
        self._pki_cert_issuer_details = None
        self._ssh_cert_issuer_details = None
        self.discriminator = None

        if cert_issuer_type is not None:
            self.cert_issuer_type = cert_issuer_type
        if max_ttl is not None:
            self.max_ttl = max_ttl
        if pki_cert_issuer_details is not None:
            self.pki_cert_issuer_details = pki_cert_issuer_details
        if ssh_cert_issuer_details is not None:
            self.ssh_cert_issuer_details = ssh_cert_issuer_details

    @property
    def cert_issuer_type(self):
        """Gets the cert_issuer_type of this CertificateIssueInfo.  # noqa: E501


        :return: The cert_issuer_type of this CertificateIssueInfo.  # noqa: E501
        :rtype: str
        """
        return self._cert_issuer_type

    @cert_issuer_type.setter
    def cert_issuer_type(self, cert_issuer_type):
        """Sets the cert_issuer_type of this CertificateIssueInfo.


        :param cert_issuer_type: The cert_issuer_type of this CertificateIssueInfo.  # noqa: E501
        :type: str
        """

        self._cert_issuer_type = cert_issuer_type

    @property
    def max_ttl(self):
        """Gets the max_ttl of this CertificateIssueInfo.  # noqa: E501


        :return: The max_ttl of this CertificateIssueInfo.  # noqa: E501
        :rtype: int
        """
        return self._max_ttl

    @max_ttl.setter
    def max_ttl(self, max_ttl):
        """Sets the max_ttl of this CertificateIssueInfo.


        :param max_ttl: The max_ttl of this CertificateIssueInfo.  # noqa: E501
        :type: int
        """

        self._max_ttl = max_ttl

    @property
    def pki_cert_issuer_details(self):
        """Gets the pki_cert_issuer_details of this CertificateIssueInfo.  # noqa: E501


        :return: The pki_cert_issuer_details of this CertificateIssueInfo.  # noqa: E501
        :rtype: PKICertificateIssueDetails
        """
        return self._pki_cert_issuer_details

    @pki_cert_issuer_details.setter
    def pki_cert_issuer_details(self, pki_cert_issuer_details):
        """Sets the pki_cert_issuer_details of this CertificateIssueInfo.


        :param pki_cert_issuer_details: The pki_cert_issuer_details of this CertificateIssueInfo.  # noqa: E501
        :type: PKICertificateIssueDetails
        """

        self._pki_cert_issuer_details = pki_cert_issuer_details

    @property
    def ssh_cert_issuer_details(self):
        """Gets the ssh_cert_issuer_details of this CertificateIssueInfo.  # noqa: E501


        :return: The ssh_cert_issuer_details of this CertificateIssueInfo.  # noqa: E501
        :rtype: SSHCertificateIssueDetails
        """
        return self._ssh_cert_issuer_details

    @ssh_cert_issuer_details.setter
    def ssh_cert_issuer_details(self, ssh_cert_issuer_details):
        """Sets the ssh_cert_issuer_details of this CertificateIssueInfo.


        :param ssh_cert_issuer_details: The ssh_cert_issuer_details of this CertificateIssueInfo.  # noqa: E501
        :type: SSHCertificateIssueDetails
        """

        self._ssh_cert_issuer_details = ssh_cert_issuer_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CertificateIssueInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CertificateIssueInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "akeyless"
VERSION = "3.1.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Akeyless API",
    author="Akeyless",
    author_email="support@akeyless.io",
    url="https://www.akeyless.io/",
    keywords=["OpenAPI", "OpenAPI-Generator", "Akeyless API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    The purpose of this application is to provide access to Akeyless API.  # noqa: E501
    """
)
